.. Invenio-SWORD documentation master file, created by
   sphinx-quickstart on Thu Dec  5 16:26:24 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Invenio-SWORD's documentation!
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   configuration
   features
   development
   api/index


invenio-sword is an implementation of the `SWORD deposit protocol <https://swordapp.github.io/swordv3/swordv3.html>`_
for the `Invenio <https://inveniosoftware.org/>`_ ecosystem, building on the `invenio-deposit
<https://github.com/inveniosoftware/invenio-deposit>`_ component.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
